==> blesta-5.10.2.zip: blesta/language/uk_ua/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Група редагування';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Впровадити електронні адреси як імена користувачів';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Використовуйте налаштування компанії (зніміть галочку, щоб вказати нижче)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Способи доставки рахунків-фактур';
$lang['AdminCompanyGroups.edit.field_description'] = 'Опис';
$lang['AdminCompanyGroups.edit.field_color'] = 'Колір';
$lang['AdminCompanyGroups.edit.field_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Обов\'язкові поля клієнта';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Загальні налаштування клієнта';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Повідомлення';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Доставка рахунку-фактури';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Штрафи за прострочення';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Параметри виставлення рахунків та списання коштів';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Основні опції';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Група редагування';
$lang['AdminCompanyGroups.edit.page_title'] = 'Налаштування > Компанія > Групи клієнтів > Редагувати групу';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Створити групу';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Увімкнути перевірку електронної пошти';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Впровадити електронні адреси як імена користувачів';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Використовуйте налаштування компанії (зніміть галочку, щоб вказати нижче)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Способи доставки рахунків-фактур';
$lang['AdminCompanyGroups.add.field_description'] = 'Опис';
$lang['AdminCompanyGroups.add.field_color'] = 'Колір';
$lang['AdminCompanyGroups.add.field_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Обов\'язкові поля клієнта';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Загальні налаштування клієнта';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Повідомлення';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Доставка рахунку-фактури';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Штрафи за прострочення';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Параметри виставлення рахунків та списання коштів';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Основні опції';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Створити групу';
$lang['AdminCompanyGroups.add.page_title'] = 'Налаштування > Компанія > Групи клієнтів > Створити групу';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Ви впевнені, що хочете видалити цю групу клієнтів? Всі клієнти з цієї групи будуть переміщені до групи за замовчуванням.';
$lang['AdminCompanyGroups.index.no_results'] = 'Немає груп клієнтів.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Видалити';
$lang['AdminCompanyGroups.index.option_edit'] = 'Редагувати';
$lang['AdminCompanyGroups.index.text_options'] = 'Параметри';
$lang['AdminCompanyGroups.index.text_clients'] = 'Кількість клієнтів';
$lang['AdminCompanyGroups.index.text_description'] = 'Опис';
$lang['AdminCompanyGroups.index.text_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Створити групу';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Групи клієнтів';
$lang['AdminCompanyGroups.index.page_title'] = 'Налаштування > Компанія > Групи клієнтів';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Поставте галочку, щоб надсилати лист з підтвердженням електронної пошти, коли створюється новий логін або клієнт змінює свою електронну пошту. Повідомлення з\'явиться в профілі клієнта, поки він не буде верифікований.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Видаляє можливість клієнтам визначати власне ім\'я користувача.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s є групою за замовчуванням і не може бути видалена.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s успішно видалено!';
$lang['AdminCompanyGroups.!success.edit_updated'] = 'Файл %1$s успішно відредаговано!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s успішно створено!';

==> blesta-5.11.4.zip: blesta/language/uk_ua/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Група редагування';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Впровадити електронні адреси як імена користувачів';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Використовуйте налаштування компанії (зніміть галочку, щоб вказати нижче)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Способи доставки рахунків-фактур';
$lang['AdminCompanyGroups.edit.field_description'] = 'Опис';
$lang['AdminCompanyGroups.edit.field_color'] = 'Колір';
$lang['AdminCompanyGroups.edit.field_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Обов\'язкові поля клієнта';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Загальні налаштування клієнта';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Повідомлення';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Доставка рахунку-фактури';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Штрафи за прострочення';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Параметри виставлення рахунків та списання коштів';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Основні опції';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Група редагування';
$lang['AdminCompanyGroups.edit.page_title'] = 'Налаштування > Компанія > Групи клієнтів > Редагувати групу';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Створити групу';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Увімкнути перевірку електронної пошти';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Впровадити електронні адреси як імена користувачів';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Використовуйте налаштування компанії (зніміть галочку, щоб вказати нижче)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Способи доставки рахунків-фактур';
$lang['AdminCompanyGroups.add.field_description'] = 'Опис';
$lang['AdminCompanyGroups.add.field_color'] = 'Колір';
$lang['AdminCompanyGroups.add.field_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Обов\'язкові поля клієнта';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Загальні налаштування клієнта';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Повідомлення';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Доставка рахунку-фактури';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Штрафи за прострочення';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Параметри виставлення рахунків та списання коштів';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Основні опції';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Створити групу';
$lang['AdminCompanyGroups.add.page_title'] = 'Налаштування > Компанія > Групи клієнтів > Створити групу';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Ви впевнені, що хочете видалити цю групу клієнтів? Всі клієнти з цієї групи будуть переміщені до групи за замовчуванням.';
$lang['AdminCompanyGroups.index.no_results'] = 'Немає груп клієнтів.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Видалити';
$lang['AdminCompanyGroups.index.option_edit'] = 'Редагувати';
$lang['AdminCompanyGroups.index.text_options'] = 'Параметри';
$lang['AdminCompanyGroups.index.text_clients'] = 'Кількість клієнтів';
$lang['AdminCompanyGroups.index.text_description'] = 'Опис';
$lang['AdminCompanyGroups.index.text_name'] = 'Ім\'я';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Створити групу';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Групи клієнтів';
$lang['AdminCompanyGroups.index.page_title'] = 'Налаштування > Компанія > Групи клієнтів';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Поставте галочку, щоб надсилати лист з підтвердженням електронної пошти, коли створюється новий логін або клієнт змінює свою електронну пошту. Повідомлення з\'явиться в профілі клієнта, поки він не буде верифікований.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Видаляє можливість клієнтам визначати власне ім\'я користувача.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s є групою за замовчуванням і не може бути видалена.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s успішно видалено!';
$lang['AdminCompanyGroups.!success.edit_updated'] = 'Файл %1$s успішно відредаговано!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s успішно створено!';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Дозволені шлюзи';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Дозволені шлюзи';
